# coding=utf-8
from __future__ import absolute_import, division, print_function

from .service import preferences

__all__ = ["preferences"]
